@@ -48,7 +48,7 @@ def document_dataframe(
     period_type: PeriodType = None,
     identifier_key: Literal["ticker", "CIK"] = "ticker",
     block_tag_names: Sequence[str] = [],
-    use_fiscal_period=False,
+    use_fiscal_period=True,
 ) -> "pd.DataFrame":
     """Disclosures/Footnotes in a DataFrame
 
@@ -56,17 +56,19 @@ def document_dataframe(
     :param disclosure_names: The sections to retrieve, see the full list @ https://www.calcbench.com/disclosure_list.  You cannot request XBRL and non-XBRL sections in the same request.  eg.  ['Management's Discussion And Analysis', 'Risk Factors']
     :param all_history: Search all time periods
     :param year: The year to search
-    :param period: period of data to get.  0 for annual data, 1, 2, 3, 4 for quarterly data.
-    :param period_type: "quarterly" or "annual", only applicable when other period data not supplied.  Use "annual" to only search end-of-year documents.
+    :param period: period of data to get
+    :param period_type: Only applicable when other period data not supplied.  Use "annual" to only search end-of-year documents.
     :param progress_bar: Pass a tqdm progress bar to keep an eye on things.
-    :param identifier_key: "ticker" or "CIK", how to index the returned DataFrame.
-    :return: A DataFrame indexed by document name -> company identifier.
+    :param identifier_key: how to index the returned DataFrame.
+    :return: A DataFrame of DocumentSearchResults indexed by document name -> company identifier.
 
     Usage::
 
-      >>> data = calcbench.document_dataframe(company_identifiers=["msft", "goog"], all_history=True, disclosure_names=["Management's Discussion And Analysis", "Risk Factors"])
-      >>> data = data.fillna(False)
-      >>> word_counts = data.applymap(lambda document: document and len(document.get_contents_text().split()))
+      >>> data = calcbench.document_dataframe(company_identifiers=["msft", "goog"],
+      >>>                                     all_history=True,
+      >>>                                     disclosure_names=["ManagementsDiscussionAndAnalysis", "RiskFactors"])
+      >>> word_counts = data.applymap(lambda document: document.get_contents_text().split()
+      >>>                             na_action="ignore")
 
     """
     if block_tag_names:
@@ -98,6 +100,7 @@ def document_dataframe(
             )
         )
     period_map = {"1Q": 1, "2Q": 2, "3Q": 3, "Y": 4}
+    data = pd.DataFrame()
     for doc in docs:
         period_year = doc["fiscal_year" if use_fiscal_period else "calendar_year"]
         if period in ("Y", 0) or period_type == "annual":
@@ -113,10 +116,17 @@ def document_dataframe(
                 p = None
             else:
                 p = pd.Period(year=period_year, quarter=quarter, freq="q")  # type: ignore
-        doc["period"] = p
-        doc[identifier_key] = (doc[identifier_key] or "").upper()
-        doc["value"] = doc
-    data = pd.DataFrame(docs)
+        data = data.append(
+            {
+                **doc,
+                **{
+                    "period": p,
+                    identifier_key: (doc[identifier_key] or ""),
+                    "value": doc,
+                },
+            },
+            ignore_index=True,
+        )
     data = data.set_index(keys=[identifier_key, "disclosure_type_name", "period"])  # type: ignore
     data = data.loc[~data.index.duplicated()]  # type:ignore There can be duplicates
     data = data.unstack("disclosure_type_name")["value"]  # type: ignore
@@ -323,7 +333,10 @@ def document_search(
        >>> import tqdm
        >>> sp500 = calcbench.tickers(index='SP500')
        >>> with tqdm.tqdm() as progress_bar:
-       >>>     risk_factors = list(calcbench.document_search(company_identifiers=sp500, disclosure_names=['Risk Factors'], all_history=True, progress_bar=progress_bar))
+       >>>     risk_factors = list(calcbench.document_search(company_identifiers=sp500,
+       >>>                         disclosure_names=['Risk Factors'],
+       >>>                         all_history=True,
+       >>>                         progress_bar=progress_bar))
 
     """
     if not any(
@@ -414,4 +427,13 @@ def _document_by_block_tag_name(
 ) -> DisclosureContent:
     payload = {"accession_ids": accession_id, "block_tag_name": block_tag_name}
     json = _json_GET("query/disclosuresByTag", payload)
-    return DisclosureContent(**json[0])
\ No newline at end of file
+    return DisclosureContent(**json[0])
+
+
+if __name__ == "__main__":
+    document_dataframe(
+        company_identifiers=["msft", "goog"],
+        all_history=True,
+        disclosure_names=["ManagementsDiscussionAndAnalysis", "RiskFactors"],
+        use_fiscal_period=True,
+    )
